Re: Please pull 'libertas-fixes' branch of wireless-2.6

2007-07-02 Thread Jeff Garzik

John W. Linville wrote:

The following changes since commit 189548642c5962e60c3667bdb3a703fe0bed12a6:
  Linus Torvalds (1):
Linus 2.6.22-rc6

are found in the git repository at:

  git://git.kernel.org/pub/scm/linux/kernel/git/linville/wireless-2.6.git 
libertas-fixes

Dan Williams (4):
  libertas: style fixes
  libertas: kill wlan_scan_process_results
  libertas: fix WPA associations by handling ENABLE_RSN correctly
  libertas: remove private ioctls

 drivers/net/wireless/libertas/Makefile  |2 +-
 drivers/net/wireless/libertas/README|  275 
 drivers/net/wireless/libertas/assoc.c   |   28 +-
 drivers/net/wireless/libertas/cmd.c |   12 +-
 drivers/net/wireless/libertas/cmdresp.c |   21 +
 drivers/net/wireless/libertas/hostcmd.h |2 +-
 drivers/net/wireless/libertas/ioctl.c   | 1081 ---
 drivers/net/wireless/libertas/main.c|8 +-
 drivers/net/wireless/libertas/scan.c|   51 +--
 drivers/net/wireless/libertas/wext.c|  152 -
 drivers/net/wireless/libertas/wext.h|   45 +--
 11 files changed, 79 insertions(+), 1598 deletions(-)
 delete mode 100644 drivers/net/wireless/libertas/ioctl.c


pulled


-
To unsubscribe from this list: send the line unsubscribe netdev in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Please pull 'libertas-fixes' branch of wireless-2.6

2007-06-27 Thread John W. Linville
The following changes since commit 189548642c5962e60c3667bdb3a703fe0bed12a6:
  Linus Torvalds (1):
Linus 2.6.22-rc6

are found in the git repository at:

  git://git.kernel.org/pub/scm/linux/kernel/git/linville/wireless-2.6.git 
libertas-fixes

Dan Williams (4):
  libertas: style fixes
  libertas: kill wlan_scan_process_results
  libertas: fix WPA associations by handling ENABLE_RSN correctly
  libertas: remove private ioctls

 drivers/net/wireless/libertas/Makefile  |2 +-
 drivers/net/wireless/libertas/README|  275 
 drivers/net/wireless/libertas/assoc.c   |   28 +-
 drivers/net/wireless/libertas/cmd.c |   12 +-
 drivers/net/wireless/libertas/cmdresp.c |   21 +
 drivers/net/wireless/libertas/hostcmd.h |2 +-
 drivers/net/wireless/libertas/ioctl.c   | 1081 ---
 drivers/net/wireless/libertas/main.c|8 +-
 drivers/net/wireless/libertas/scan.c|   51 +--
 drivers/net/wireless/libertas/wext.c|  152 -
 drivers/net/wireless/libertas/wext.h|   45 +--
 11 files changed, 79 insertions(+), 1598 deletions(-)
 delete mode 100644 drivers/net/wireless/libertas/ioctl.c

diff --git a/drivers/net/wireless/libertas/Makefile 
b/drivers/net/wireless/libertas/Makefile
index a1097f5..32ed413 100644
--- a/drivers/net/wireless/libertas/Makefile
+++ b/drivers/net/wireless/libertas/Makefile
@@ -2,7 +2,7 @@ libertas-objs := main.o fw.o wext.o \
rx.o tx.o cmd.o   \
cmdresp.o scan.o  \
join.o 11d.o  \
-   ioctl.o debugfs.o \
+   debugfs.o \
ethtool.o assoc.o
 
 usb8xxx-objs += if_bootcmd.o
diff --git a/drivers/net/wireless/libertas/README 
b/drivers/net/wireless/libertas/README
index 1f92f50..0b133ce 100644
--- a/drivers/net/wireless/libertas/README
+++ b/drivers/net/wireless/libertas/README
@@ -28,281 +28,6 @@ DRIVER LOADING
 
insmod usb8388.ko [fw_name=usb8388.bin]
 
-=
-IWPRIV COMMAND
-=
-
-NAME
-   This manual describes the usage of private commands used in Marvell WLAN
-   Linux Driver. All the commands available in Wlanconfig will not be 
available
-   in the iwpriv.
-
-SYNOPSIS
-   iwpriv ethX command [sub-command] ...
-
-   iwpriv ethX setregioncode n
-   iwpriv ethX getregioncode
-
-Version 5 Command:
-   iwpriv ethX ledgpio n
-
-BT Commands:
-   The blinding table (BT) contains a list of mac addresses that will be,
-   by default, ignored by the firmware. It is also possible to invert this
-   behavior so that we will ignore all traffic except for the portion
-   coming from mac addresess in the list. It is primarily used for
-   debugging and testing networks.  It can be edited and inspected with
-   the following commands:
-
-   iwpriv ethX bt_reset
-   iwpriv ethX bt_add mac_address
-   iwpriv ethX bt_del mac_address
-   iwpriv ethX bt_list id
-   iwpriv ethX bt_get_invert n
-   iwpriv ethX bt_set_invert n
-
-FWT Commands:
-   The forwarding table (FWT) is a feature used to manage mesh network
-   routing in the firmware.  The FWT is essentially a routing table that
-   associates a destination mac address (da) with a next hop receiver
-   address (ra).  The FWT can be inspected and edited with the following
-   iwpriv commands, which are described in greater detail below.
-   Eventually, the table will be automatically maintained by a custom
-   routing protocol.
-
-   NOTE: FWT commands replace the previous DFT commands.  What were the DFT
-   commands?, you might ask.  They were an earlier API to the firmware that
-   implemented a simple MAC-layer forwarding mechanism.  In the unlikely
-   event that you were using these commands, you must migrate to the new
-   FWT commands which can be used to achieve the same functionality.
-
-   iwpriv ethX fwt_add [parameters]
-   iwpriv ethX fwt_del [parameters]
-   iwpriv ethX fwt_lookup [parameters]
-   iwpriv ethX fwt_list [parameters]
-   iwpriv ethX fwt_list_route [parameters]
-   iwpriv ethX fwt_list_neigh [parameters]
-   iwpriv ethX fwt_reset [parameters]
-   iwpriv ethX fwt_cleanup
-   iwpriv ethX fwt_time
-
-MESH Commands:
-
-   The MESH commands are used to configure various features of the mesh
-   routing protocol.  The following commands are supported:
-
-   iwpriv ethX mesh_get_ttl
-   iwpriv ethX mesh_set_ttl ttl
-
-DESCRIPTION
-   Those commands are used to send additional commands to the Marvell WLAN
-   card via the Linux device driver.
-
-   The ethX parameter specifies the network device that is to be used to
-   perform this command on. it could be eth0, eth1 etc.
-
-setregioncode
-   This command is used to set the region code in the station.
-   where value is 'region 

Please pull 'libertas-fixes' branch of wireless-2.6

2007-06-12 Thread John W. Linville
Fixes identified by the libertas team as important for 2.6.22...

---

The following changes since commit 717c9339202a42ae7bec7d3c4b84deecdcae9f81:
  Dan Williams (1):
libertas: reduce SSID and BSSID mixed-case abuse

are found in the git repository at:

  git://git.kernel.org/pub/scm/linux/kernel/git/linville/wireless-2.6.git 
libertas-fixes

Dan Williams (1):
  libertas: actually send mesh frames to mesh netdev

Luis Carlos (1):
  libertas: convert libertas_mpp into anycast_mask

Luis Carlos Cobo Rus (2):
  libertas: pull current channel from firmware on mesh autostart
  libertas: deauthenticate from AP in channel switch

 drivers/net/wireless/libertas/assoc.c   |   13 +
 drivers/net/wireless/libertas/assoc.h   |2 ++
 drivers/net/wireless/libertas/cmdresp.c |1 +
 drivers/net/wireless/libertas/dev.h |1 +
 drivers/net/wireless/libertas/host.h|4 ++--
 drivers/net/wireless/libertas/main.c|   27 ++-
 drivers/net/wireless/libertas/rx.c  |5 ++---
 7 files changed, 35 insertions(+), 18 deletions(-)

diff --git a/drivers/net/wireless/libertas/assoc.c 
b/drivers/net/wireless/libertas/assoc.c
index ee82413..f67efa0 100644
--- a/drivers/net/wireless/libertas/assoc.c
+++ b/drivers/net/wireless/libertas/assoc.c
@@ -200,6 +200,14 @@ static int update_channel(wlan_private * priv)
cmd_option_waitforrsp, 0, NULL);
 }
 
+void libertas_sync_channel(struct work_struct *work)
+{
+   wlan_private *priv = container_of(work, wlan_private, sync_channel);
+
+   if (update_channel(priv) != 0)
+   lbs_pr_info(Channel synchronization failed.);
+}
+
 static int assoc_helper_channel(wlan_private *priv,
 struct assoc_request * assoc_req)
 {
@@ -403,6 +411,11 @@ static int should_deauth_infrastructure(wlan_adapter 
*adapter,
return 1;
}
 
+   if (test_bit(ASSOC_FLAG_CHANNEL, assoc_req-flags)) {
+   lbs_deb_assoc(Deauthenticating due to channel switch.\n);
+   return 1;
+   }
+
/* FIXME: deal with 'auto' mode somehow */
if (test_bit(ASSOC_FLAG_MODE, assoc_req-flags)) {
if (assoc_req-mode != IW_MODE_INFRA)
diff --git a/drivers/net/wireless/libertas/assoc.h 
b/drivers/net/wireless/libertas/assoc.h
index b5eddf8..5e9c31f 100644
--- a/drivers/net/wireless/libertas/assoc.h
+++ b/drivers/net/wireless/libertas/assoc.h
@@ -9,6 +9,8 @@ void libertas_association_worker(struct work_struct *work);
 
 struct assoc_request * wlan_get_association_request(wlan_adapter *adapter);
 
+void libertas_sync_channel(struct work_struct *work);
+
 #define ASSOC_DELAY (HZ / 2)
 static inline void wlan_postpone_association_work(wlan_private *priv)
 {
diff --git a/drivers/net/wireless/libertas/cmdresp.c 
b/drivers/net/wireless/libertas/cmdresp.c
index ebedd63..0c3b9a5 100644
--- a/drivers/net/wireless/libertas/cmdresp.c
+++ b/drivers/net/wireless/libertas/cmdresp.c
@@ -987,6 +987,7 @@ int libertas_process_event(wlan_private * priv)
netif_carrier_on(priv-mesh_dev) ;
}
adapter-mode = IW_MODE_ADHOC ;
+   schedule_work(priv-sync_channel);
break;
 
default:
diff --git a/drivers/net/wireless/libertas/dev.h 
b/drivers/net/wireless/libertas/dev.h
index d6c340a..785192b 100644
--- a/drivers/net/wireless/libertas/dev.h
+++ b/drivers/net/wireless/libertas/dev.h
@@ -150,6 +150,7 @@ struct _wlan_private {
 
struct delayed_work assoc_work;
struct workqueue_struct *assoc_thread;
+   struct work_struct sync_channel;
 
/** Hardware access */
int (*hw_register_dev) (wlan_private * priv);
diff --git a/drivers/net/wireless/libertas/host.h 
b/drivers/net/wireless/libertas/host.h
index cedf1db..7509cc1 100644
--- a/drivers/net/wireless/libertas/host.h
+++ b/drivers/net/wireless/libertas/host.h
@@ -310,8 +310,8 @@ enum cmd_mesh_access_opts {
cmd_act_mesh_get_ttl = 1,
cmd_act_mesh_set_ttl,
cmd_act_mesh_get_stats,
-   cmd_act_mesh_get_mpp,
-   cmd_act_mesh_set_mpp,
+   cmd_act_mesh_get_anycast,
+   cmd_act_mesh_set_anycast,
 };
 
 /** Card Event definition */
diff --git a/drivers/net/wireless/libertas/main.c 
b/drivers/net/wireless/libertas/main.c
index ec9be0c..623ab4b 100644
--- a/drivers/net/wireless/libertas/main.c
+++ b/drivers/net/wireless/libertas/main.c
@@ -178,45 +178,45 @@ u16 libertas_region_code_to_index[MRVDRV_MAX_REGION_CODE] 
=
  */
 
 /**
  * @brief Get function for sysfs attribute libertas_mpp
  */
-static ssize_t libertas_mpp_get(struct device * dev,
+static ssize_t libertas_anycast_get(struct device * dev,
struct device_attribute *attr, char * buf) {
struct cmd_ds_mesh_access mesh_access;
 
memset(mesh_access, 0, sizeof(mesh_access));

Re: Please pull 'libertas-fixes' branch of wireless-2.6

2007-06-12 Thread Jeff Garzik

John W. Linville wrote:

Fixes identified by the libertas team as important for 2.6.22...

---

The following changes since commit 717c9339202a42ae7bec7d3c4b84deecdcae9f81:
  Dan Williams (1):
libertas: reduce SSID and BSSID mixed-case abuse

are found in the git repository at:

  git://git.kernel.org/pub/scm/linux/kernel/git/linville/wireless-2.6.git 
libertas-fixes

Dan Williams (1):
  libertas: actually send mesh frames to mesh netdev

Luis Carlos (1):
  libertas: convert libertas_mpp into anycast_mask

Luis Carlos Cobo Rus (2):
  libertas: pull current channel from firmware on mesh autostart
  libertas: deauthenticate from AP in channel switch


Just to be clear, you intend 'libertas' and 'libertas-fixes' (in that 
order) for 2.6.22, and 'libertas-upstream' for 2.6.23?


Jeff



-
@@ -178,45 +178,45 @@ u16 libertas_region_code_to_index[MRVDRV_MAX_REGION_CODE] 
 
 /**
- * @brief Get function for sysfs attribute libertas_mpp
+ * @brief Get function for sysfs attribute anycast_mask
  */
To unsubscribe from this list: send the line unsubscribe netdev in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: Please pull 'libertas-fixes' branch of wireless-2.6

2007-06-12 Thread John W. Linville
On Tue, Jun 12, 2007 at 06:54:35PM -0400, Jeff Garzik wrote:
 John W. Linville wrote:
 Fixes identified by the libertas team as important for 2.6.22...
 
 ---
 
 The following changes since commit 
 717c9339202a42ae7bec7d3c4b84deecdcae9f81:
   Dan Williams (1):
 libertas: reduce SSID and BSSID mixed-case abuse
 
 are found in the git repository at:
 
   git://git.kernel.org/pub/scm/linux/kernel/git/linville/wireless-2.6.git 
   libertas-fixes
 
 Dan Williams (1):
   libertas: actually send mesh frames to mesh netdev
 
 Luis Carlos (1):
   libertas: convert libertas_mpp into anycast_mask
 
 Luis Carlos Cobo Rus (2):
   libertas: pull current channel from firmware on mesh autostart
   libertas: deauthenticate from AP in channel switch
 
 Just to be clear, you intend 'libertas' and 'libertas-fixes' (in that 
 order) for 2.6.22, and 'libertas-upstream' for 2.6.23?

Yes, correct.

Thanks,

John
-- 
John W. Linville
[EMAIL PROTECTED]
-
To unsubscribe from this list: send the line unsubscribe netdev in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: Please pull 'libertas-fixes' branch of wireless-2.6

2007-06-12 Thread Jeff Garzik

John W. Linville wrote:

Fixes identified by the libertas team as important for 2.6.22...

---

The following changes since commit 717c9339202a42ae7bec7d3c4b84deecdcae9f81:
  Dan Williams (1):
libertas: reduce SSID and BSSID mixed-case abuse

are found in the git repository at:

  git://git.kernel.org/pub/scm/linux/kernel/git/linville/wireless-2.6.git 
libertas-fixes

Dan Williams (1):
  libertas: actually send mesh frames to mesh netdev

Luis Carlos (1):
  libertas: convert libertas_mpp into anycast_mask

Luis Carlos Cobo Rus (2):
  libertas: pull current channel from firmware on mesh autostart
  libertas: deauthenticate from AP in channel switch

 drivers/net/wireless/libertas/assoc.c   |   13 +
 drivers/net/wireless/libertas/assoc.h   |2 ++
 drivers/net/wireless/libertas/cmdresp.c |1 +
 drivers/net/wireless/libertas/dev.h |1 +
 drivers/net/wireless/libertas/host.h|4 ++--
 drivers/net/wireless/libertas/main.c|   27 ++-
 drivers/net/wireless/libertas/rx.c  |5 ++---
 7 files changed, 35 insertions(+), 18 deletions(-)


pulled into #upstream-fixes


-
To unsubscribe from this list: send the line unsubscribe netdev in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html